function [data, auxData, metaData, txtData, weights] = mydata_Aythya_valisineria

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Aves'; 
metaData.order      = 'Anseriformes'; 
metaData.family     = 'Anatidae';
metaData.species    = 'Aythya_valisineria'; 
metaData.species_en = 'Canvasback'; 

metaData.ecoCode.climate = {'Cfb', 'Dfc'};
metaData.ecoCode.ecozone = {'THn'};
metaData.ecoCode.habitat = {'biFp', 'biFm'};
metaData.ecoCode.embryo  = {'Tnsf'};
metaData.ecoCode.migrate = {'Ms'};
metaData.ecoCode.food    = {'biCi', 'biCim', 'xiHl'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};

metaData.T_typical  = C2K(41.2); % K, body temp
metaData.data_0     = {'ab'; 'ax'; 'aR'; 'am'; 'Wwb'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author    = {'Bas Kooijman'};    
metaData.date_subm = [2018 09 24];              
metaData.email     = {'bas.kooijman@vu.nl'};            
metaData.address   = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight@akvaplan.niva.no'}; 
metaData.date_acc    = [2018 09 24]; 

%% set data
% zero-variate data

data.ab = 24;   units.ab = 'd';    label.ab = 'age at birth';                  bibkey.ab = 'AnAge';   
  temp.ab = C2K(36.65);  units.temp.ab = 'K'; label.temp.ab = 'temperature';
data.tx = 74;     units.tx = 'd';    label.tx = 'time since birth at fledching'; bibkey.tx = 'LighAnkn1984';   
  temp.tx = C2K(41.2);  units.temp.tx = 'K'; label.temp.tx = 'temperature';
data.tR = 365;    units.tR = 'd';    label.tR = 'time since birth at 1st brood'; bibkey.tR = 'Wiki';
  temp.tR = C2K(41.2);  units.temp.tR = 'K'; label.temp.tR = 'temperature';
data.am = 29.5*365;  units.am = 'd';    label.am = 'life span';                     bibkey.am = 'AnAge';   
  temp.am = C2K(41.2);  units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Wwb = 44.8;  units.Wwb = 'g';   label.Wwb = 'wet weight at birth';          bibkey.Wwb = 'LighAnkn1984';
data.Wwi = 1152; units.Wwi = 'g';   label.Wwi = 'ultimate wet weight';       bibkey.Wwi = 'Wiki';
data.Wwim = 1252; units.Wwim = 'g';   label.Wwim = 'ultimate wet weight of males';       bibkey.Wwim = 'Wiki';

data.Ri  = 9/365;   units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';  bibkey.Ri  = 'ADW';   
  temp.Ri = C2K(41.2);    units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
 
% uni-variate data
% t-W data
data.tW = [ ... % time (wk), wet weight (g)
1.698	65.296
7.330	130.703
13.353	219.422
20.418	373.414
31.286	532.177
39.782	791.066
49.745	830.967
60.096	924.473
73.864	948.175]; 
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(41.2);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW = 'LighAnkn1984';
  
%% set weights for all real data
weights = setweights(data, []);
weights.tW = 5 * weights.tW;
weights.Wwi = 5 * weights.Wwi;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
%txtData.comment = comment;

%% Discussion points
D2 = 'males are supposed to differ from females by {p_Am} only';
D1 = 'body temperature is guessed';
metaData.discussion = struct('D1', D1,'D2', D2);

%% Links
metaData.links.id_CoL = 'K56Z'; % Cat of Life
metaData.links.id_ITIS = '175129'; % ITIS
metaData.links.id_EoL = '45510575'; % Ency of Life
metaData.links.id_Wiki = 'Aythya_valisineria'; % Wikipedia
metaData.links.id_ADW = 'Aythya_valisineria'; % ADW
metaData.links.id_Taxo = '93182'; % Taxonomicon
metaData.links.id_WoRMS = '159173'; % WoRMS
metaData.links.id_avibase = '1929E1E16E073570'; % avibase
metaData.links.id_birdlife = 'canvasback-aythya-valisineria'; % birdlife
metaData.links.id_AnAge = 'Aythya_valisineria'; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Canvasback}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'LighAnkn1984'; type = 'Article'; bib = [ ... 
'author = {J. P. Lightbody and C. D. Ankney}, ' ... 
'year = {1984}, ' ...
'title = {SEASONAL INFLUENCE ON THE STRATEGIES OF GROWTH AND DEVELOPMENT OF CANVASBACK AND LESSER SCAUP DUCKLINGS}, ' ...
'journal = {The Auk}, ' ...
'volume = {101}, ' ...
'pages = {121-133}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'AnAge'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Aythya_fuligula}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'ADW'; type = 'Misc'; bib = ...
'howpublished = {\url{http://animaldiversity.org/accounts/Canvasback/}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];